@@ -36,6 +36,7 @@ COMPUTE_ID = uuidutils.generate_uuid()
 PORT_ID = uuidutils.generate_uuid()
 SUBNET_ID = uuidutils.generate_uuid()
 NETWORK_ID = uuidutils.generate_uuid()
+SG_ID = uuidutils.generate_uuid()
 IP_ADDRESS = "172.24.41.1"
 VIP = o_data_models.Vip(port_id=t_constants.MOCK_PORT_ID,
                         subnet_id=t_constants.MOCK_SUBNET_ID,
@@ -985,12 +986,14 @@ class TestNetworkTasks(base.TestCase):
     def test_update_vip_sg(self, mock_session, mock_lb_get,
                            mock_get_net_driver):
         mock_driver = mock.MagicMock()
+        mock_driver.update_vip_sg.return_value = SG_ID
         mock_lb_get.return_value = LB
         mock_get_net_driver.return_value = mock_driver
         net = network_tasks.UpdateVIPSecurityGroup()
 
-        net.execute(self.load_balancer_mock)
+        sg_id = net.execute(self.load_balancer_mock)
         mock_driver.update_vip_sg.assert_called_once_with(LB, LB.vip)
+        self.assertEqual(sg_id, SG_ID)
 
     def test_get_subnet_from_vip(self, mock_get_net_driver):
         mock_driver = mock.MagicMock()
